@@ -1,6 +1,4 @@
 import sys
-import os
-import re
 import json
 import time
 import click
@@ -71,8 +69,8 @@ def wait(timeout, interval, feedsready, servicesready):
     """
     Wait for an image to go to analyzed or analysis_failed status with a specific timeout
 
-    :param timeout: 
-    :param interval: 
+    :param timeout:
+    :param interval:
     :param feedsready:
     :return:
     """
@@ -88,8 +86,8 @@ def wait(timeout, interval, feedsready, servicesready):
             try:
                 anchorecli.cli.utils.check_access(config)
                 _logger.debug("check access success")
-                break;
-            except Exception as err:
+                break
+            except Exception:
                 _logger.debug("check access failed, trying again")
             time.sleep(interval)
         else:
@@ -127,7 +125,7 @@ def wait(timeout, interval, feedsready, servicesready):
 
                     if False not in all_up.values():
                         _logger.debug("full set of available engine services detected")
-                        break;
+                        break
                     else:
                         _logger.debug("service set not yet available {}".format(all_up))
                 elif ret.get('httpcode', 500) in [401]:
@@ -200,10 +198,12 @@ def delete(host_id, servicename):
 
     anchorecli.cli.utils.doexit(ecode)
 
+
 @system.group(name="feeds", short_help="Feed data operations")
 def feeds():
     pass
 
+
 @feeds.command(name="list", short_help="Get a list of loaded data feeds.")
 def list():
     ecode = 0
@@ -237,7 +237,7 @@ def feedsync(flush):
             except NameError:
                 pass
             answer = input("Really perform a manual feed data sync/flush? (y/N)")
-        except Exception as err:
+        except Exception:
             answer = "n"
 
         if 'y' == answer.lower():
@@ -255,3 +255,71 @@ def feedsync(flush):
             ecode = 2
 
     anchorecli.cli.utils.doexit(ecode)
+
+
+@feeds.command(name="config", short_help="Enable a specific feed and or group so that it will sync data on the next sync")
+@click.option('--group', help='Config a specific group only')
+@click.option('--enable', help='Enable the feed/group', is_flag=True)
+@click.option('--disable', help='Disable the feed/group', is_flag=True)
+@click.argument('feed')
+def toggle_enabled(feed, group=None, enable=None, disable=None):
+    ecode = 0
+
+    try:
+        if not enable and not disable:
+            raise Exception('Must set one of --enable or --disable')
+        elif enable and disable:
+            raise Exception('Can set only one of --enable or --disable')
+        else:
+            enabled = enable
+
+        if group:
+            ret = anchorecli.clients.apiexternal.system_feed_group_enable_toggle(config, feed, group, enabled=enabled)
+            ecode = anchorecli.cli.utils.get_ecode(ret)
+        else:
+            ret = anchorecli.clients.apiexternal.system_feed_enable_toggle(config, feed, enabled=enabled)
+            ecode = anchorecli.cli.utils.get_ecode(ret)
+
+        if ret['success']:
+            if group:
+                print(anchorecli.cli.utils.format_output(config, 'system_feed_groups', {}, [ret['payload']]))
+            else:
+                print(anchorecli.cli.utils.format_output(config, 'system_feeds_list', {}, [ret['payload']]))
+        else:
+            raise Exception(json.dumps(ret['error'], indent=4))
+
+    except Exception as err:
+        print(anchorecli.cli.utils.format_error_output(config, 'system_feeds_enable', {}, err))
+        if not ecode:
+            ecode = 2
+
+    anchorecli.cli.utils.doexit(ecode)
+
+
+@feeds.command(name="delete", short_help="Delete the feed data for a feed or group. Metadata will remain but all feed data and vuln matches (if applicable) are removed")
+@click.option('--group', help='Delete data for a specific group only')
+@click.argument('feed')
+def delete_data(feed, group=None):
+    ecode = 0
+    try:
+        if group:
+            ret = anchorecli.clients.apiexternal.system_feed_group_delete(config, feed, group)
+            ecode = anchorecli.cli.utils.get_ecode(ret)
+        else:
+            ret = anchorecli.clients.apiexternal.system_feed_delete(config, feed)
+            ecode = anchorecli.cli.utils.get_ecode(ret)
+
+        if ret['success']:
+            if group:
+                print(anchorecli.cli.utils.format_output(config, 'system_feed_groups', {}, [ret['payload']]))
+            else:
+                print(anchorecli.cli.utils.format_output(config, 'system_feeds_list', {}, [ret['payload']]))
+        else:
+            raise Exception(json.dumps(ret['error'], indent=4))
+
+    except Exception as err:
+        print(anchorecli.cli.utils.format_error_output(config, 'system_feeds_flush', {}, err))
+        if not ecode:
+            ecode = 2
+
+    anchorecli.cli.utils.doexit(ecode)
