@@ -1,15 +1,14 @@
 import json
 import re
 import requests
-import hashlib
 import logging
 import urllib3
 import requests.packages.urllib3
 try:
     from urllib.parse import urlparse, urlunparse, urlencode, quote
-except:
+except ImportError:
     from urllib import urlencode, quote
-    from urlparse import urlparse,urlunparse
+    from urlparse import urlparse, urlunparse
 
 requests.packages.urllib3.disable_warnings(requests.packages.urllib3.exceptions.InsecureRequestWarning)
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
@@ -22,7 +21,7 @@ header_overrides = {'Content-Type': 'application/json'}
 
 
 def set_account_header(config):
-    _logger.info('As Account = {}'.format(config.get('as_account')))
+    _logger.debug('As Account = {}'.format(config.get('as_account')))
     if config['as_account'] is not None:
         header_overrides['x-anchore-account'] = config['as_account']
     else:
@@ -85,7 +84,92 @@ def system_feeds_sync(config, flush=False):
     except Exception as err:
         raise err
 
-    return(ret)    
+    return(ret)
+
+
+def system_feed_enable_toggle(config, feed, enabled):
+    userId = config['user']
+    password = config['pass']
+    base_url = config['url']
+
+    ret = {}
+
+    base_url = re.sub("/$", "", base_url)
+    url = '/'.join([base_url, "system/feeds/{}?enabled={}".format(feed, enabled)])
+    set_account_header(config)
+    try:
+        _logger.debug("PUT url="+str(url))
+        _logger.debug("PUT insecure="+str(config['ssl_verify']))
+        r = requests.put(url, auth=(userId, password), verify=config['ssl_verify'], headers=header_overrides)
+        ret = anchorecli.clients.common.make_client_result(r, raw=False)
+    except Exception as err:
+        raise err
+
+    return ret
+
+
+def system_feed_group_enable_toggle(config, feed, group, enabled):
+    userId = config['user']
+    password = config['pass']
+    base_url = config['url']
+
+    ret = {}
+
+    base_url = re.sub("/$", "", base_url)
+    url = '/'.join([base_url, "system/feeds/{}/{}?enabled={}".format(feed, group, enabled)])
+    set_account_header(config)
+    try:
+        _logger.debug("PUT url="+str(url))
+        _logger.debug("PUT insecure="+str(config['ssl_verify']))
+        r = requests.put(url, auth=(userId, password), verify=config['ssl_verify'], headers=header_overrides)
+        ret = anchorecli.clients.common.make_client_result(r, raw=False)
+    except Exception as err:
+        raise err
+
+    return ret
+
+
+def system_feed_delete(config, feed):
+    userId = config['user']
+    password = config['pass']
+    base_url = config['url']
+
+    ret = {}
+
+    base_url = re.sub("/$", "", base_url)
+    url = '/'.join([base_url, "system/feeds/{}".format(feed)])
+    set_account_header(config)
+    try:
+        _logger.debug("DELETE url="+str(url))
+        _logger.debug("DELETE insecure="+str(config['ssl_verify']))
+        r = requests.delete(url, auth=(userId, password), verify=config['ssl_verify'], headers=header_overrides)
+        ret = anchorecli.clients.common.make_client_result(r, raw=False)
+    except Exception as err:
+        raise err
+
+    return ret
+
+
+def system_feed_group_delete(config, feed, group):
+    userId = config['user']
+    password = config['pass']
+    base_url = config['url']
+
+    ret = {}
+
+    base_url = re.sub("/$", "", base_url)
+    url = '/'.join([base_url, "system/feeds/{}/{}".format(feed, group)])
+    set_account_header(config)
+    try:
+        _logger.debug("DELETE url="+str(url))
+        _logger.debug("DELETE insecure="+str(config['ssl_verify']))
+        r = requests.delete(url, auth=(userId, password), verify=config['ssl_verify'], headers=header_overrides)
+        ret = anchorecli.clients.common.make_client_result(r, raw=False)
+    except Exception as err:
+        raise err
+
+    return ret
+
 
 def system_status(config):
     userId = config['user']
@@ -115,7 +199,7 @@ def delete_system_service(config, host_id, servicename):
     if not host_id or not servicename:
         raise Exception("invalid host_id or servicename given")
 
-    ret = {}    
+    ret = {}
 
     base_url = re.sub("/$", "", base_url)
     url = '/'.join([base_url, "system", "services", servicename, host_id])
@@ -332,7 +416,7 @@ def import_image(config, anchore_data=[]):
     ret = []
 
     payload = anchore_data[0]
-    
+
     base_url = re.sub("/$", "", base_url)
     url = '/'.join([base_url, "imageimport"])
     set_account_header(config)
@@ -356,7 +440,7 @@ def query_image(config, imageDigest=None, query_group=None, query_type=None, ven
 
     base_url = re.sub("/$", "", base_url)
     url = '/'.join([base_url, "images", imageDigest])
-    
+
     if query_group:
         url = '/'.join([url, query_group])
     else:
@@ -458,7 +542,7 @@ def get_policy(config, policyId=None, detail=False):
         _logger.debug("GET url="+str(url))
         r = requests.get(url, auth=(userId, password), verify=config['ssl_verify'], headers=header_overrides)
         ret = anchorecli.clients.common.make_client_result(r, raw=False)
-        
+
     except Exception as err:
         raise err
 
@@ -578,7 +662,7 @@ def activate_subscription(config, subscription_type, subscription_key):
 
     ret = {}
 
-    # first - get the subscription record from engine, to get the right subscription_id for the record 
+    # first - get the subscription record from engine, to get the right subscription_id for the record
     try:
         subscription_response = get_subscription(config, subscription_type, subscription_key)
         subscription_records = subscription_response.get('payload', [])
@@ -594,7 +678,7 @@ def activate_subscription(config, subscription_type, subscription_key):
 
     base_url = re.sub("/$", "", base_url)
     url = '/'.join([base_url, "subscriptions", subscription_id])
-    
+
     payload = {'active':True, 'subscription_key': subscription_key, 'subscription_type': subscription_type}
     set_account_header(config)
 
@@ -614,7 +698,7 @@ def deactivate_subscription(config, subscription_type, subscription_key):
 
     ret = {}
 
-    # first - get the subscription record from engine, to get the right subscription_id for the record 
+    # first - get the subscription record from engine, to get the right subscription_id for the record
     try:
         subscription_response = get_subscription(config, subscription_type, subscription_key)
         subscription_records = subscription_response.get('payload', [])
@@ -672,7 +756,7 @@ def delete_subscription(config, subscription_type=None, subscription_key=None):
 
     ret = {}
 
-    # first - get the subscription record from engine, to get the right subscription_id for the record 
+    # first - get the subscription record from engine, to get the right subscription_id for the record
     try:
         subscription_response = get_subscription(config, subscription_type, subscription_key)
         subscription_records = subscription_response.get('payload', [])
@@ -697,7 +781,7 @@ def delete_subscription(config, subscription_type=None, subscription_key=None):
     except Exception as err:
         raise err
 
-    return(ret)    
+    return(ret)
 
 def get_subscription(config, subscription_type=None, subscription_key=None):
     userId = config['user']
@@ -772,13 +856,8 @@ def add_repo(config, input_repo, autosubscribe=False, lookuptag=None):
     return(ret)
     #return(add_subscription(config, 'repo_update', input_repo))
 
+
 def get_repo(config, input_repo=None):
-    userId = config['user']
-    password = config['pass']
-    base_url = config['url']
-
-    ret = {}
-
     set_account_header(config)
 
     filtered_records = []
@@ -792,7 +871,7 @@ def get_repo(config, input_repo=None):
 
     subscriptions['payload'] = filtered_records
 
-    return(subscriptions)
+    return subscriptions
 
 def delete_repo(config, input_repo, force=False):
     return(delete_subscription(config, 'repo_update', input_repo))
@@ -948,7 +1027,7 @@ def describe_error_codes(config):
     except Exception as err:
         raise err
 
-    return(ret)    
+    return(ret)
 
 def describe_policy_spec(config):
     userId = config['user']
@@ -1154,7 +1233,7 @@ def query_images_by_vulnerability(config, vulnerability_id, namespace=None, affe
         query_params['severity'] = severity
     if vendor_only:
         query_params['vendor_only'] = vendor_only
-    
+
     if query_params:
         url = "{}&{}".format(url, urlencode(query_params))
 
@@ -1189,7 +1268,7 @@ def query_images_by_package(config, name, version=None, package_type=None):
         query_params['version'] = version
     if package_type:
         query_params['package_type'] = package_type
-    
+
     if query_params:
         url = "{}&{}".format(url, urlencode(query_params))
 
@@ -1469,7 +1548,7 @@ def update_user_password(config, account_name=None, user_name=None, user_passwor
     except Exception as err:
         raise err
 
-    return(ret)        
+    return(ret)
 
 
 def list_archives(config):
